==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/DependentStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface DependentStatusFluent<A extends DependentStatusFluent<A>> extends Fluent<A> {


    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(int[] arg1,int arg2,int arg3);
    public A withNewGroup(char[] arg1);
    public A withNewGroup(StringBuffer arg1);
    public A withNewGroup(byte[] arg1,int arg2);
    public A withNewGroup(byte[] arg1);
    public A withNewGroup(char[] arg1,int arg2,int arg3);
    public A withNewGroup(byte[] arg1,int arg2,int arg3);
    public A withNewGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGroup(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(int[] arg1,int arg2,int arg3);
    public A withNewStatus(char[] arg1);
    public A withNewStatus(StringBuffer arg1);
    public A withNewStatus(byte[] arg1,int arg2);
    public A withNewStatus(byte[] arg1);
    public A withNewStatus(char[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatus(String arg1);
    public String getUuid();
    public A withUuid(String uuid);
    public Boolean hasUuid();
    public A withNewUuid(StringBuilder arg1);
    public A withNewUuid(int[] arg1,int arg2,int arg3);
    public A withNewUuid(char[] arg1);
    public A withNewUuid(StringBuffer arg1);
    public A withNewUuid(byte[] arg1,int arg2);
    public A withNewUuid(byte[] arg1);
    public A withNewUuid(char[] arg1,int arg2,int arg3);
    public A withNewUuid(byte[] arg1,int arg2,int arg3);
    public A withNewUuid(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUuid(String arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(int[] arg1,int arg2,int arg3);
    public A withNewVersion(char[] arg1);
    public A withNewVersion(StringBuffer arg1);
    public A withNewVersion(byte[] arg1,int arg2);
    public A withNewVersion(byte[] arg1);
    public A withNewVersion(char[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVersion(String arg1);
}

==> openshift-model-operatorhub-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/DependentStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface DependentStatusFluent<A extends DependentStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getGroup();
    public A withGroup(String group);
    public Boolean hasGroup();
    public A withNewGroup(StringBuilder arg1);
    public A withNewGroup(int[] arg1,int arg2,int arg3);
    public A withNewGroup(char[] arg1);
    public A withNewGroup(StringBuffer arg1);
    public A withNewGroup(byte[] arg1,int arg2);
    public A withNewGroup(byte[] arg1);
    public A withNewGroup(char[] arg1,int arg2,int arg3);
    public A withNewGroup(byte[] arg1,int arg2,int arg3);
    public A withNewGroup(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGroup(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getStatus();
    public A withStatus(String status);
    public Boolean hasStatus();
    public A withNewStatus(StringBuilder arg1);
    public A withNewStatus(int[] arg1,int arg2,int arg3);
    public A withNewStatus(char[] arg1);
    public A withNewStatus(StringBuffer arg1);
    public A withNewStatus(byte[] arg1,int arg2);
    public A withNewStatus(byte[] arg1);
    public A withNewStatus(char[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3);
    public A withNewStatus(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStatus(String arg1);
    public String getUuid();
    public A withUuid(String uuid);
    public Boolean hasUuid();
    public A withNewUuid(StringBuilder arg1);
    public A withNewUuid(int[] arg1,int arg2,int arg3);
    public A withNewUuid(char[] arg1);
    public A withNewUuid(StringBuffer arg1);
    public A withNewUuid(byte[] arg1,int arg2);
    public A withNewUuid(byte[] arg1);
    public A withNewUuid(char[] arg1,int arg2,int arg3);
    public A withNewUuid(byte[] arg1,int arg2,int arg3);
    public A withNewUuid(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUuid(String arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(int[] arg1,int arg2,int arg3);
    public A withNewVersion(char[] arg1);
    public A withNewVersion(StringBuffer arg1);
    public A withNewVersion(byte[] arg1,int arg2);
    public A withNewVersion(byte[] arg1);
    public A withNewVersion(char[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3);
    public A withNewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVersion(String arg1);
}
